@@ -26,6 +26,9 @@
 (defvar mc-pgp-path "pgp" "*The PGP executable.")
 (defvar mc-pgp-display-snarf-output nil
   "*If t, pop up the PGP output window when snarfing keys.")
+(defvar mc-pgp-always-fetch nil
+  "*If t, always fetch missing keys. If nil, prompt user. If 'never,
+never fetch keys, and don't ask.")
 (defvar mc-pgp-alternate-keyring nil
   "*Public keyring to use instead of default.")
 (defvar mc-pgp-comment
@@ -33,13 +36,13 @@
   "*Comment field to appear in ASCII armor output.  If nil, let PGP
 use its default.")
 
-(defconst mc-pgp-msg-begin-line "-----BEGIN PGP MESSAGE-----"
+(defconst mc-pgp-msg-begin-line "^-----BEGIN PGP MESSAGE-----\r?$"
   "Text for start of PGP message delimiter.")
-(defconst mc-pgp-msg-end-line "-----END PGP MESSAGE-----\n?"
+(defconst mc-pgp-msg-end-line "^-----END PGP MESSAGE-----\r?$"
   "Text for end of PGP message delimiter.")
-(defconst mc-pgp-signed-begin-line "-----BEGIN PGP SIGNED MESSAGE-----"
+(defconst mc-pgp-signed-begin-line "^-----BEGIN PGP SIGNED MESSAGE-----\r?$"
   "Text for start of PGP signed messages.")
-(defconst mc-pgp-signed-end-line "-----END PGP SIGNATURE-----"
+(defconst mc-pgp-signed-end-line "^-----END PGP SIGNATURE-----\r?$"
   "Text for end of PGP signed messages.")
 (defconst mc-pgp-key-begin-line "^-----BEGIN PGP PUBLIC KEY BLOCK-----\r?$"
   "Text for start of PGP public key.")
@@ -53,7 +56,7 @@ use its default.")
   "Regular expression matching a PGP key snarf message")
 (defconst mc-pgp-nokey-re
   "Cannot find the public key matching userid '\\(.+\\)'$"
-  "Regular expression matching a PGP missing-key messsage")
+  "Regular expression matching a PGP missing-key message")
 (defconst mc-pgp-key-expected-re
   "Key matching expected Key ID \\(\\S +\\) not found")
 
@@ -95,7 +98,7 @@ PGP ID.")
 	   "^\\(\\(pub\\|sec\\)\\s +[^/]+/\\(\\S *\\)\\s +\\S +\\s +\\(.*\\)\\)$")
 	  (revoke-regexp "REVOKED")
 	  (obuf (current-buffer))
-	  buffer)
+	  buffer key-start key-end)
       (if (null result)
 	  (unwind-protect
 	      (progn
@@ -311,6 +314,13 @@ PGP ID.")
 	 (re-search-forward "^File is conventionally encrypted" nil t)))
       (if (null key) (mc-deactivate-passwd t))
       (mc-pgp-decrypt-region start end "***** CONVENTIONAL *****"))
+     ;; Or maybe this is the wrong PGP version
+     ((save-excursion
+	(and
+	 (set-buffer buffer)
+	 (goto-char (point-min))
+	 (re-search-forward "Unsupported packet format" nil t)))
+      (mc-message mc-pgp-error-re buffer "Not encrypted for PGP 2.6"))
      (t
       (mc-display-buffer buffer)
       (if (mc-message "^\aError: +Bad pass phrase\\.$" buffer)
